<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'atto_chemistry', language 'id', version '5.0'.
 *
 * @package     atto_chemistry
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['cursorinfo'] = 'Panah menunjukkan posisi elemen baru dari pustaka elemen akan disisipkan.';
$string['delay'] = 'Tunda sebelum pembaruan';
$string['delay_desc'] = 'Waktu dalam milidetik editor akan menunggu setelah input berhenti untuk memperbarui pratinjau. Nilai 0 akan memperbarui pratinjau terus menerus, tetapi dapat menyebabkan beban server yang berlebihan pada situs yang sibuk.';
$string['editchemistry'] = 'Edit kimia menggunakan <a href="{$a}" target="_blank"> TeX mhchem </a>';
$string['librarygroup1'] = 'Rumus';
$string['librarygroup1_desc'] = 'Perintah TeX tercantum di tab rumus.';
$string['librarygroup1_title'] = 'Rumus';
$string['librarygroup2'] = 'Simbol dan satuan';
$string['librarygroup2_desc'] = 'Perintah TeX tercantum di tab simbol dan unit.';
$string['librarygroup2_title'] = 'Simbol dan satuan';
$string['librarygroup3'] = 'Obligasi & panah';
$string['librarygroup3_desc'] = 'Perintah TeX yang terdaftar di tab simbol obligasi dan panah.';
$string['librarygroup3_title'] = 'Ikatan, reaksi dan panah kesetimbangan';
$string['librarygroup4'] = 'Yunani';
$string['librarygroup4_desc'] = 'Perintah TeX terdaftar di tab simbol yunani.';
$string['librarygroup4_title'] = 'Simbol Yunani';
$string['librarygroup5'] = 'Miring';
$string['librarygroup5_desc'] = 'Perintah TeX tercantum di tab simbol miring.';
$string['librarygroup5_title'] = 'Karakter miring';
$string['librarygroup6'] = 'H-Cn';
$string['librarygroup6_desc'] = 'Perintah TeX tertera pada elemen: tab H-Cn.';
$string['librarygroup6_title'] = 'Tabel unsur periodik';
$string['librarygroup7'] = 'La-Lu & Ac-Lr';
$string['librarygroup7_desc'] = 'Perintah TeX terdaftar pada elemen: tab La-Lu dan Ac-Lr.';
$string['librarygroup7_title'] = 'Elemen lantanoid dan akinoid';
$string['pluginname'] = 'Editor kimia';
$string['preview'] = 'Pratinjau kimia';
$string['savechemistry'] = 'Simpan kimia';
$string['settings'] = 'Pengaturan editor kimia';
$string['update'] = 'Memperbarui';
